==> librenms-24.8.1v0.tgz: librenms/lang/pt-BR/wireless.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Wireless Sensors Language Lines
    |--------------------------------------------------------------------------
    |
    | As seguintes linhas de linguagem são usadas para traduzir nomes e unidades de sensores sem fio
    |
    */

    'title' => 'Sem Fio',
    'ap-count' => [
        'short' => 'APs',
        'long' => 'Contagem de APs',
        'unit' => '',
    ],
    'clients' => [
        'short' => 'Clientes',
        'long' => 'Contagem de Clientes',
        'unit' => '',
    ],
    'capacity' => [
        'short' => 'Capacidade',
        'long' => 'Capacidade',
        'unit' => '%',
    ],
    'ccq' => [
        'short' => 'CCQ',
        'long' => 'Qualidade de Conexão do Cliente',
        'unit' => '%',
    ],
    'errors' => [
        'short' => 'Erros',
        'long' => 'Contagem de Erros',
        'unit' => '',
    ],
    'error-ratio' => [
        'short' => 'Taxa de Erros',
        'long' => 'Taxa de Erros por Bit/Pacote',
        'unit' => '%',
    ],
    'error-rate' => [
        'short' => 'Taxa de Erros',
        'long' => 'Taxa de Erros por Bit',
        'unit' => 'bps',
    ],
    'frequency' => [
        'short' => 'Frequência',
        'long' => 'Frequência',
        'unit' => 'MHz',
    ],
    'distance' => [
        'short' => 'Distância',
        'long' => 'Distância',
        'unit' => 'm',
    ],
    'mse' => [
        'short' => 'EMQ',
        'long' => 'Erro Médio Quadrático',
        'unit' => 'dB',
    ],
    'noise-floor' => [
        'short' => 'Ruído de Fundo',
        'long' => 'Ruído de Fundo',
        'unit' => 'dBm',
    ],
    'power' => [
        'short' => 'Potência/Sinal',
        'long' => 'Potência ou Sinal TX/RX',
        'unit' => 'dBm',
    ],
    'quality' => [
        'short' => 'Qualidade',
        'long' => 'Qualidade',
        'unit' => '%',
    ],
    'rate' => [
        'short' => 'Taxa',
        'long' => 'Taxa TX/RX',
        'unit' => 'bps',
    ],
    'rssi' => [
        'short' => 'RSSI',
        'long' => 'Indicador de Força do Sinal Recebido',
        'unit' => 'dBm',
    ],
    'snr' => [
        'short' => 'SNR',
        'long' => 'Relação Sinal-Ruído',
        'unit' => 'dB',
    ],
    'sinr' => [
        'short' => 'SINR',
        'long' => 'Relação Sinal-Interferência-Mais-Ruído',
        'unit' => 'dB',
    ],
    'rsrq' => [
        'short' => 'RSRQ',
        'long' => 'Qualidade do Sinal de Referência Recebido',
        'unit' => 'dB',
    ],
    'rsrp' => [
        'short' => 'RSRP',
        'long' => 'Potência dos Sinais de Referência Recebidos',
        'unit' => 'dBm',
    ],
    'ssr' => [
        'short' => 'RSS',
        'long' => 'Relação de Força do Sinal',
        'unit' => 'dB',
    ],
    'utilization' => [
        'short' => 'Utilização',
        'long' => 'Utilização',
        'unit' => '%',
    ],
    'xpi' => [
        'short' => 'XPI',
        'long' => 'Interferência de Polarização Cruzada',
        'unit' => 'dB',
    ],
    'cell' => [
        'short' => 'Célula',
        'long' => 'Célula',
        'unit' => '',
    ],
    'channel' => [
        'short' => 'Canal',
        'long' => 'Canal',
        'unit' => '',
    ],
];

==> librenms-25.11.0v0.tgz: librenms/lang/pt-BR/wireless.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Wireless Sensors Language Lines
    |--------------------------------------------------------------------------
    |
    | As seguintes linhas de linguagem são usadas para traduzir nomes e unidades de sensores wireless
    |
    */

    'title' => 'Wireless',
    'ap-count' => [
        'short' => 'APs',
        'long' => 'Contagem de Pontos de Acesso',
        'unit' => '',
    ],
    'clients' => [
        'short' => 'Clientes',
        'long' => 'Contagem de Clientes',
        'unit' => '',
    ],
    'capacity' => [
        'short' => 'Capacidade',
        'long' => 'Capacidade',
        'unit' => '%',
    ],
    'ccq' => [
        'short' => 'CCQ',
        'long' => 'Qualidade de Conexão do Cliente',
        'unit' => '%',
    ],
    'errors' => [
        'short' => 'Erros',
        'long' => 'Contagem de Erros',
        'unit' => '',
    ],
    'error-ratio' => [
        'short' => 'Taxa de Erros',
        'long' => 'Taxa de Erros por Bit/Pacote',
        'unit' => '%',
    ],
    'error-rate' => [
        'short' => 'Taxa de Erros',
        'long' => 'Taxa de Erros por Bit',
        'unit' => 'bps',
    ],
    'frequency' => [
        'short' => 'Frequência',
        'long' => 'Frequência',
        'unit' => 'MHz',
    ],
    'distance' => [
        'short' => 'Distância',
        'long' => 'Distância',
        'unit' => 'm',
    ],
    'mse' => [
        'short' => 'EMQ',
        'long' => 'Erro Médio Quadrático',
        'unit' => 'dB',
    ],
    'noise-floor' => [
        'short' => 'Ruído de Fundo',
        'long' => 'Ruído de Fundo',
        'unit' => 'dBm',
    ],
    'power' => [
        'short' => 'Potência/Sinal',
        'long' => 'Potência ou Sinal TX/RX',
        'unit' => 'dBm',
    ],
    'quality' => [
        'short' => 'Qualidade',
        'long' => 'Qualidade',
        'unit' => '%',
    ],
    'rate' => [
        'short' => 'Taxa',
        'long' => 'Taxa TX/RX',
        'unit' => 'bps',
    ],
    'rssi' => [
        'short' => 'RSSI',
        'long' => 'Indicador de Força do Sinal Recebido',
        'unit' => 'dBm',
    ],
    'snr' => [
        'short' => 'SNR',
        'long' => 'Relação Sinal-Ruído',
        'unit' => 'dB',
    ],
    'sinr' => [
        'short' => 'SINR',
        'long' => 'Relação Sinal-Interferência-Mais-Ruído',
        'unit' => 'dB',
    ],
    'rsrq' => [
        'short' => 'RSRQ',
        'long' => 'Qualidade do Sinal de Referência Recebido',
        'unit' => 'dB',
    ],
    'rsrp' => [
        'short' => 'RSRP',
        'long' => 'Potência dos Sinais de Referência Recebidos',
        'unit' => 'dBm',
    ],
    'ssr' => [
        'short' => 'RSS',
        'long' => 'Relação de Força do Sinal',
        'unit' => 'dB',
    ],
    'utilization' => [
        'short' => 'Utilização',
        'long' => 'Utilização',
        'unit' => '%',
    ],
    'xpi' => [
        'short' => 'XPI',
        'long' => 'Interferência de Polarização Cruzada',
        'unit' => 'dB',
    ],
    'cell' => [
        'short' => 'Célula',
        'long' => 'Célula',
        'unit' => '',
    ],
    'channel' => [
        'short' => 'Canal',
        'long' => 'Canal',
        'unit' => '',
    ],
];
